@@ -16,7 +16,9 @@ Usage::
     session_client: STSClient = session.client("sts")
     ```
 """
-from mypy_boto3_sts.client import STSClient as Client, STSClient
+from mypy_boto3_sts.client import STSClient
+
+Client = STSClient
 
 
 __all__ = ("Client", "STSClient")
